@@ -1,6 +1,6 @@
 from typing import List
-from typing import Union
 from enum import Enum
+from typing import Union
 from dataclasses import dataclass
 
 
@@ -204,8 +204,10 @@ class NodeType(Enum):
     Dataset = "Dataset"
     RepresentationBlock = "RepresentationBlock"
     GroundTruth = "GroundTruth"
+    CustomLayer = "CustomLayer"
     CustomLoss = "CustomLoss"
     Visualizer = "Visualizer"
+    Metric = "Metric"
     Lambda = "Lambda"
     TFOpLambda = "TFOpLambda"
     SlicingOpLambda = "SlicingOpLambda"
@@ -1689,6 +1691,11 @@ class GroundTruth:
     type: NodeType
 
 
+@dataclass
+class CustomLayer:
+    type: NodeType
+
+
 @dataclass
 class CustomLoss:
     type: NodeType
@@ -1699,6 +1706,11 @@ class Visualizer:
     type: NodeType
 
 
+@dataclass
+class Metric:
+    type: NodeType
+
+
 @dataclass
 class Lambda:
     type: NodeType
@@ -1761,5 +1773,6 @@ class NodeDataTypes:
                  CategoricalCrossentropy, CategoricalHinge, CosineSimilarity, Hinge, Huber, KLDivergence, LogCosh, 
                  MeanAbsoluteError, MeanAbsolutePercentageError, MeanSquaredError, MeanSquaredLogarithmicError, Poisson, 
                  SquaredHinge, Adadelta, Adagrad, Adam, Adamax, Ftrl, Nadam, RMSprop, SGD, OnnxAbs, OnnxErf, 
-                 OnnxHardSigmoid, OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLoss, 
-                 Visualizer, Lambda, TFOpLambda, SlicingOpLambda, Repeat, Variable, Gather, FixedDropout]
+                 OnnxHardSigmoid, OnnxReduceMean, OnnxSqrt, Dataset, RepresentationBlock, GroundTruth, CustomLayer, 
+                 CustomLoss, Visualizer, Metric, Lambda, TFOpLambda, SlicingOpLambda, Repeat, Variable, Gather, 
+                 FixedDropout]
